Welcome to django-mptt2 documentation!
======================================

.. include:: ../../README.rst

Contents
--------


.. toctree::

   install
   tutorial
   admin
   development
   changelog
   docstrings